/**
 * Returns true if the needle is contained in the haystack.
 *
 * @param needle
 * @param haystack
 * @example
 * ```ts
 * contains('foo', ['foo', 'bar']) // true
 * contains('foo', ['bar']) // false
 * ```
 */
export declare function contains(needle: string, haystack: string[]): boolean;
/**
 * Returns true if all needles are contained in the haystack.
 * @param needles
 * @param haystack
 * @example
 * ```ts
 * containsAll(['foo', 'bar'], ['foo', 'bar', 'baz']) // true
 * containsAll(['foo', 'bar'], ['foo', 'baz']) // false
 * ```
 */
export declare function containsAll(needles: string[], haystack: string[]): boolean;
/**
 * Returns true if any needle is contained in the haystack.
 * @param needles
 * @param haystack
 * @example
 * ```ts
 * containsAny(['foo', 'bar'], ['foo', 'bar', 'baz']) // true
 * containsAny(['foo', 'bar'], ['foo', 'baz']) // true
 * containsAny(['foo', 'bar'], ['baz']) // false
 * ```
 */
export declare function containsAny(needles: string[], haystack: string[]): boolean;
/**
 * Returns true if none of the needles are contained in the haystack.
 * @param needles
 * @param haystack
 * @example
 * ```ts
 * containsNone(['foo', 'bar'], ['foo', 'bar', 'baz']) // false
 * containsNone(['foo', 'bar'], ['foo', 'baz']) // false
 * containsNone(['foo', 'bar'], ['baz']) // true
 * ```
 */
export declare function containsNone(needles: string[], haystack: string[]): boolean;
/**
 * Returns true if all needles are contained in the haystack.
 * @param needles
 * @param haystack
 * @example
 * ```ts
 * containsOnly(['foo', 'bar'], ['foo', 'bar', 'baz']) // false
 * containsOnly(['foo', 'bar'], ['foo', 'baz']) // false
 * containsOnly(['foo', 'bar'], ['foo', 'bar']) // true
 * ```
 */
export declare function containsOnly(needles: string[], haystack: string[]): boolean;
/**
 * Returns true if the needle is not contained in the haystack.
 * @param needle
 * @param haystack
 * @example
 * ```ts
 * doesNotContain('foo', ['foo', 'bar']) // false
 * doesNotContain('foo', ['bar']) // true
 * ```
 */
export declare function doesNotContain(needle: string, haystack: string[]): boolean;
